@@ -7,13 +7,10 @@ App::Parcimonie::Applet - systray applet object monitoring parcimonie's activiti
 =cut
 
 package App::Parcimonie::Applet;
-use Any::Moose;
-with 'App::Parcimonie::Role::HasEncoding';
-
-our $VERSION = '0.7.1'; # VERSION
+use Moo;
+use MooX::late;
 
 use 5.10.0;
-use namespace::autoclean;
 
 use Encode;
 
@@ -30,6 +27,10 @@ textdomain("parcimonie-applet");
 
 use Try::Tiny;
 
+use namespace::clean;
+
+with 'App::Parcimonie::Role::HasEncoding';
+
 
 =head1 ATTRIBUTES
 
@@ -164,7 +165,7 @@ b) the "Artistic License" which comes with Perl.
     $icon->signal_connect('button-press-event' => sub {
         my $ticon = shift;
         my $event = shift;
-        return unless $event->button->{button} == 1;
+        return unless $event->button == 1;
         if ($self->monitorwin->get_visible) {
             $self->monitorwin->hide;
         }
@@ -312,5 +313,6 @@ sub now_resting {
     return;
 }
 
-no Any::Moose;
+no Moo;
+
 1;
