@@ -9,14 +9,14 @@ package App::Parcimonie::DBus::Object;
 use strict;
 use warnings;
 
-our $VERSION = '0.7.1'; # VERSION
-
 # We're going to be a DBus object
 use base qw{Net::DBus::Object};
 
 # Specify the main interface provided by our object
 use Net::DBus::Exporter qw{org.parcimonie.daemon};
 
+use namespace::clean;
+
 sub new {
     my $class = shift;
     my $service = shift;
