@@ -9,101 +9,94 @@ Have a look to bin/parcimonie for a full-blown real life usage example.
 =cut
 
 package App::Parcimonie::Daemon;
-use Any::Moose;
-
-our $VERSION = '0.7.1'; # VERSION
-
-with 'App::Parcimonie::Role::HasEncoding';
-with any_moose('X::Getopt::Dashes');
+use Moo;
+use MooX::late;
 
 use 5.10.1;
-use namespace::autoclean;
 use App::Parcimonie;
 use App::Parcimonie::DBus::Object;
 use Encode;
 use English qw{-no_match_vars};
-use File::Spec;
-use List::MoreUtils qw{any};
+use List::MoreUtils qw{any}; # XXX: Perl 5.20: use the version from List::Util
 use Net::DBus;
 use Net::DBus::Reactor;
 use Net::DBus::Service;
 use Net::DBus::Test::MockObject;
-use Tie::Cache;
 use Time::Duration::Parse qw(parse_duration);
 use Try::Tiny;
-use Any::Moose 'X::Types::Path::Class';
-use Any::Moose '::Util::TypeConstraints';
+use Type::Utils qw{declare as where coerce from};
+use Types::Path::Tiny qw{Dir};
+use Types::Standard qw{Str Num};
+use namespace::clean;
+
+with 'App::Parcimonie::Role::HasEncoding';
+use MooX::Options;
+
+
+=head1 TYPES
+
+=cut
+
+my $DurationInSeconds = declare as Num, where { $_ > 0 };
+coerce $DurationInSeconds, from Str, sub { parse_duration($_) };
 
 =head1 ATTRIBUTES
 
 =cut
 
-has 'verbose'  => (
+option 'verbose'  => (
     documentation => q{Use this option to get more output.},
     isa => 'Bool', is => 'ro', default => 0
 );
 
-has '+codeset'  => ( metaclass => 'NoGetopt' );
-has '+encoding' => ( metaclass => 'NoGetopt' );
-
-has 'gnupg_homedir' => (
+option 'gnupg_homedir' => (
     documentation => q{GnuPG homedir.},
-    isa           => 'Path::Class::Dir',
+    isa           => Dir,
     is            => 'ro',
-    coerce        => 1,
+    format        => 's',
+    coerce        => Dir->coercion,
 );
 
-has 'gnupg_extra_args' => (
+option 'gnupg_extra_args' => (
     documentation => q{Extra argument passed to GnuPG. Use this option once per needed argument.},
-    metaclass     => any_moose('X::Getopt::Meta::Attribute'),
     cmd_flag      => 'gnupg-extra-arg',
     isa           => 'ArrayRef[Str]',
     is            => 'ro',
     default       => sub { [] },
+    format        => 's@',
 );
 
 has 'gnupg_options' => (
-    metaclass     => 'NoGetopt',
     isa           => 'HashRef',
     is            => 'ro',
     lazy_build    => 1,
 );
 
-has 'average_lapse_time' => (
+option 'average_lapse_time' => (
     documentation => q{Average lapse time between two key fetches. Can be expressed in any way understood by Time::Duration::Parse.},
-    isa           => 'Str',
-    is            => 'rw',
+    isa           => $DurationInSeconds,
+    is            => 'ro',
     predicate     => 'has_average_lapse_time',
+    format        => 's',
+    coerce        => $DurationInSeconds->coercion,
 );
 
-has 'minimum_lapse_time' => (
+option 'minimum_lapse_time' => (
     documentation => q{Minimum lapse time between two key fetches. Can be expressed in any way understood by Time::Duration::Parse. Defaults to 600 seconds.},
-    isa           => 'Str',
-    is            => 'rw',
+    isa           => $DurationInSeconds,
+    is            => 'ro',
     default       => sub { 600 },
     predicate     => 'has_minimum_lapse_time',
-);
-
-has 'last_try' => (
-    documentation => q{In-memory LRU buffer storing the result of last key fetch attempts},
-    metaclass     => 'NoGetopt',
-    isa           => 'HashRef',
-    is            => 'rw',
-    default       => sub {
-        my %last_try;
-        tie %last_try, 'Tie::Cache', { MaxCount => 1000 };
-        return \%last_try;
-    },
+    format        => 's',
+    coerce        => $DurationInSeconds->coercion,
 );
 
 has 'iterate_id' => (
-    metaclass     => 'NoGetopt',
     isa           => 'Int',
     is            => 'rw',
 );
 
 has 'dbus_object' => (
-    metaclass     => 'NoGetopt',
     isa           => 'Object',
     is            => 'rw',
     default       => sub {
@@ -121,7 +114,7 @@ has 'dbus_object' => (
     },
 );
 
-has 'gnupg_already_torified' => (
+option 'gnupg_already_torified' => (
     documentation => q{gpg is already torified somehow (e.g. gpg.conf or firewall)},
     isa       => 'Bool',
     is        => 'ro',
@@ -144,15 +137,6 @@ sub BUILD {
 
     $self->keyserver_defined_on_command_line
         or checkGpgHasDefinedKeyserver($self->gnupg_options);
-
-    # convert freeform time durations into seconds - custom types are a pain with Any::Moose :/
-    my $int_tc = find_type_constraint('Int');
-    if ($self->has_average_lapse_time && ! $int_tc->is_a_type_of($self->average_lapse_time)) {
-        $self->average_lapse_time(parse_duration($self->average_lapse_time));
-    }
-    if ($self->has_minimum_lapse_time && ! $int_tc->is_a_type_of($self->minimum_lapse_time)) {
-        $self->minimum_lapse_time(parse_duration($self->minimum_lapse_time));
-    }
 }
 
 =head2 run
@@ -264,7 +248,6 @@ sub tryRecvKey {
         $gpg_error = '';
     }
 
-    $self->set_last_try( $keyid => { success => $success, msg => $gpg_error } );
     $self->dbus_object->emit_signal("FetchEnd", $keyid, $success, $gpg_error);
 
 }
@@ -277,13 +260,17 @@ sub next_sleep_time {
             $self->average_lapse_time
             : averageLapseTime($num_public_keys);
 
-    $self->debug(sprintf('Using %s seconds as average sleep time.',
-                         $average_lapse_time
+    my $fallback_lapse_time = $self->minimum_lapse_time
+                            + rand($self->minimum_lapse_time);
+
+    $self->debug(sprintf('Using %s seconds as average sleep time, '.
+                         'and %s seconds as fallback sleep time.',
+                         $average_lapse_time, $fallback_lapse_time
     ));
 
     my $next_sleep_time = rand(2 * $average_lapse_time);
     if ($next_sleep_time < $self->minimum_lapse_time) {
-        $next_sleep_time = $self->minimum_lapse_time;
+        $next_sleep_time = $fallback_lapse_time;
     }
     return $next_sleep_time;
 }
@@ -315,21 +302,5 @@ sub iterate {
     return $next_sleep_time;
 }
 
-sub set_last_try {
-    my $self   = shift;
-    my $keyid  = shift;
-    my $result = shift;
-
-    $self->last_try->{$keyid} = $result;
-}
-
-=head1 COPYRIGHT
-
-Copyright 2010-2011 intrigeri <intrigeri@boum.org>
-
-Licensed under the same terms as Perl itself.
-
-=cut
-
-no Any::Moose;
+no Moo;
 1; # End of App::Parcimonie::Daemon
